@@ -69,6 +69,11 @@ from .alert_event_get_response import AlertEventGetResponse
 from .alert_event_response import AlertEventResponse
 from .alert_get_response import AlertGetResponse
 from .alert_response import AlertResponse
+from .alert_watcher import AlertWatcher
+from .alert_watcher_get_response import AlertWatcherGetResponse
+from .alert_watcher_patch import AlertWatcherPatch
+from .alert_watcher_post import AlertWatcherPost
+from .alert_watcher_response import AlertWatcherResponse
 from .api_client import ApiClient
 from .api_client_get_response import ApiClientGetResponse
 from .api_client_patch import ApiClientPatch
@@ -83,6 +88,18 @@ from .app_node_get_response import AppNodeGetResponse
 from .app_node_response import AppNodeResponse
 from .app_response import AppResponse
 from .array import Array
+from .array_connection import ArrayConnection
+from .array_connection_get_response import ArrayConnectionGetResponse
+from .array_connection_key import ArrayConnectionKey
+from .array_connection_key_get_response import ArrayConnectionKeyGetResponse
+from .array_connection_path import ArrayConnectionPath
+from .array_connection_path_get_response import ArrayConnectionPathGetResponse
+from .array_connection_path_response import ArrayConnectionPathResponse
+from .array_connection_post import ArrayConnectionPost
+from .array_connection_response import ArrayConnectionResponse
+from .array_factory_reset_token import ArrayFactoryResetToken
+from .array_factory_reset_token_get_response import ArrayFactoryResetTokenGetResponse
+from .array_factory_reset_token_response import ArrayFactoryResetTokenResponse
 from .array_get_response import ArrayGetResponse
 from .array_performance import ArrayPerformance
 from .array_performance_get_response import ArrayPerformanceGetResponse
@@ -96,6 +113,13 @@ from .audit_response import AuditResponse
 from .built_in import BuiltIn
 from .built_in_relationship import BuiltInRelationship
 from .built_in_resource_no_id import BuiltInResourceNoId
+from .certificate import Certificate
+from .certificate_get_response import CertificateGetResponse
+from .certificate_post import CertificatePost
+from .certificate_response import CertificateResponse
+from .certificate_signing_request import CertificateSigningRequest
+from .certificate_signing_request_post import CertificateSigningRequestPost
+from .certificate_signing_request_response import CertificateSigningRequestResponse
 from .chap import Chap
 from .connection import Connection
 from .connection_get_response import ConnectionGetResponse
@@ -137,6 +161,9 @@ from .dns import Dns
 from .dns_get_response import DnsGetResponse
 from .dns_patch import DnsPatch
 from .dns_response import DnsResponse
+from .drive import Drive
+from .drive_get_response import DriveGetResponse
+from .drive_response import DriveResponse
 from .eula import Eula
 from .eula_get_response import EulaGetResponse
 from .eula_response import EulaResponse
@@ -164,6 +191,8 @@ from .host_group_response import HostGroupResponse
 from .host_group_space import HostGroupSpace
 from .host_patch import HostPatch
 from .host_performance import HostPerformance
+from .host_performance_balance import HostPerformanceBalance
+from .host_performance_balance_get_response import HostPerformanceBalanceGetResponse
 from .host_performance_by_array import HostPerformanceByArray
 from .host_port_connectivity import HostPortConnectivity
 from .host_post import HostPost
@@ -189,6 +218,19 @@ from .member_no_id_all_get_response import MemberNoIdAllGetResponse
 from .member_no_id_all_response import MemberNoIdAllResponse
 from .member_no_id_group import MemberNoIdGroup
 from .member_response import MemberResponse
+from .network_interface import NetworkInterface
+from .network_interface_eth import NetworkInterfaceEth
+from .network_interface_fc import NetworkInterfaceFc
+from .network_interface_get_response import NetworkInterfaceGetResponse
+from .network_interface_patch import NetworkInterfacePatch
+from .network_interface_performance import NetworkInterfacePerformance
+from .network_interface_performance_eth import NetworkInterfacePerformanceEth
+from .network_interface_performance_fc import NetworkInterfacePerformanceFc
+from .network_interface_performance_get_response import NetworkInterfacePerformanceGetResponse
+from .network_interface_post import NetworkInterfacePost
+from .network_interface_response import NetworkInterfaceResponse
+from .networkinterfacepatch_eth import NetworkinterfacepatchEth
+from .networkinterfacepost_eth import NetworkinterfacepostEth
 from .new_name import NewName
 from .oauth_token_response import OauthTokenResponse
 from .offload import Offload
@@ -253,6 +295,11 @@ from .policy_rule_snapshot import PolicyRuleSnapshot
 from .policy_rule_snapshot_get_response import PolicyRuleSnapshotGetResponse
 from .policy_rule_snapshot_post import PolicyRuleSnapshotPost
 from .policy_rule_snapshot_response import PolicyRuleSnapshotResponse
+from .policy_smb import PolicySmb
+from .policy_smb_get_response import PolicySmbGetResponse
+from .policy_smb_patch import PolicySmbPatch
+from .policy_smb_post import PolicySmbPost
+from .policy_smb_response import PolicySmbResponse
 from .policymemberexportpost_members import PolicymemberexportpostMembers
 from .policymemberpost_members import PolicymemberpostMembers
 from .policyrulenfsclientpost_rules import PolicyrulenfsclientpostRules
@@ -294,6 +341,7 @@ from .remote_protection_group_get_response import RemoteProtectionGroupGetRespon
 from .remote_protection_group_response import RemoteProtectionGroupResponse
 from .remote_protection_group_snapshot import RemoteProtectionGroupSnapshot
 from .remote_protection_group_snapshot_get_response import RemoteProtectionGroupSnapshotGetResponse
+from .remote_protection_group_snapshot_post import RemoteProtectionGroupSnapshotPost
 from .remote_protection_group_snapshot_response import RemoteProtectionGroupSnapshotResponse
 from .remote_protection_group_snapshot_transfer import RemoteProtectionGroupSnapshotTransfer
 from .remote_protection_group_snapshot_transfer_get_response import RemoteProtectionGroupSnapshotTransferGetResponse
@@ -326,12 +374,37 @@ from .resource_space_get_response import ResourceSpaceGetResponse
 from .resource_space_no_id import ResourceSpaceNoId
 from .resource_space_no_id_get_response import ResourceSpaceNoIdGetResponse
 from .retention_policy import RetentionPolicy
+from .session import Session
+from .session_get_response import SessionGetResponse
 from .smis import Smis
 from .smis_get_response import SmisGetResponse
 from .smis_response import SmisResponse
+from .smtp_server import SmtpServer
+from .smtp_server_get_response import SmtpServerGetResponse
+from .smtp_server_response import SmtpServerResponse
 from .snapshot import Snapshot
 from .snapshot_schedule import SnapshotSchedule
+from .snmp_agent import SnmpAgent
+from .snmp_agent_get_response import SnmpAgentGetResponse
+from .snmp_agent_mib import SnmpAgentMib
+from .snmp_agent_mib_get_response import SnmpAgentMibGetResponse
+from .snmp_agent_mib_response import SnmpAgentMibResponse
+from .snmp_agent_patch import SnmpAgentPatch
+from .snmp_agent_response import SnmpAgentResponse
+from .snmp_manager import SnmpManager
+from .snmp_manager_get_response import SnmpManagerGetResponse
+from .snmp_manager_patch import SnmpManagerPatch
+from .snmp_manager_post import SnmpManagerPost
+from .snmp_manager_response import SnmpManagerResponse
+from .snmp_v2c import SnmpV2c
+from .snmp_v3 import SnmpV3
+from .snmp_v3_patch import SnmpV3Patch
+from .snmp_v3_post import SnmpV3Post
 from .software import Software
+from .software_bundle import SoftwareBundle
+from .software_bundle_get_response import SoftwareBundleGetResponse
+from .software_bundle_post import SoftwareBundlePost
+from .software_bundle_response import SoftwareBundleResponse
 from .software_get_response import SoftwareGetResponse
 from .software_installation import SoftwareInstallation
 from .software_installation_patch import SoftwareInstallationPatch
@@ -345,6 +418,7 @@ from .software_installations import SoftwareInstallations
 from .software_installations_get_response import SoftwareInstallationsGetResponse
 from .software_installations_response import SoftwareInstallationsResponse
 from .software_response import SoftwareResponse
+from .software_upgrade_plan import SoftwareUpgradePlan
 from .space import Space
 from .start_end_time import StartEndTime
 from .subnet import Subnet
@@ -357,6 +431,12 @@ from .support_get_response import SupportGetResponse
 from .support_patch import SupportPatch
 from .support_remote_assist_paths import SupportRemoteAssistPaths
 from .support_response import SupportResponse
+from .syslog_server import SyslogServer
+from .syslog_server_get_response import SyslogServerGetResponse
+from .syslog_server_response import SyslogServerResponse
+from .syslog_server_settings import SyslogServerSettings
+from .syslog_server_settings_get_response import SyslogServerSettingsGetResponse
+from .syslog_server_settings_response import SyslogServerSettingsResponse
 from .tag import Tag
 from .tag_get_response import TagGetResponse
 from .tag_response import TagResponse
@@ -366,8 +446,11 @@ from .test_result import TestResult
 from .test_result_get_response import TestResultGetResponse
 from .test_result_response import TestResultResponse
 from .test_result_with_resource import TestResultWithResource
+from .test_result_with_resource_get_response import TestResultWithResourceGetResponse
 from .test_result_with_resource_response import TestResultWithResourceResponse
+from .throttle import Throttle
 from .time_window import TimeWindow
+from .total_item_count_response import TotalItemCountResponse
 from .transfer import Transfer
 from .username import Username
 from .username_response import UsernameResponse
