@@ -9,6 +9,7 @@ from .blades_api import BladesApi
 from .bucket_replica_links_api import BucketReplicaLinksApi
 from .buckets_api import BucketsApi
 from .controllers_api import ControllersApi
+from .directories_api import DirectoriesApi
 from .drives_api import DrivesApi
 from .file_system_replica_links_api import FileSystemReplicaLinksApi
 from .file_system_snapshots_api import FileSystemSnapshotsApi
@@ -22,6 +23,7 @@ from .pod_replica_links_api import PodReplicaLinksApi
 from .pods_api import PodsApi
 from .policies_api import PoliciesApi
 from .ports_api import PortsApi
+from .subscriptions_api import SubscriptionsApi
 from .targets_api import TargetsApi
 from .volume_snapshots_api import VolumeSnapshotsApi
 from .volumes_api import VolumesApi
